@@ -3,17 +3,25 @@ use 5.008;
 use strict;
 use warnings;
 
-our $VERSION = '0.08'; # VERSION
+our $VERSION = '0.11'; # VERSION
 
 use Moose;
 with (
 	'Dist::Zilla::Role::FileMunger',
 	'Dist::Zilla::Role::FileFinderUser' => {
-		default_finders => [ ':InstallModules', ':ExecFiles' ],
+        default_finders => [
+            ':InstallModules',
+            (
+                eval { Dist::Zilla::Dist::Builder->VERSION('5.038'); 1 }
+                    ? ':PerlExecFiles'
+                    : ':ExecFiles'
+            )
+        ],
 	},
 	'Dist::Zilla::Role::PPI',
 );
 
+use Carp qw( confess );
 use PPI;
 use MooseX::Types::Perl qw( LaxVersionStr );
 use namespace::autoclean;
@@ -36,7 +44,7 @@ sub munge_file {
 	my $version = $self->zilla->version;
 
 	confess 'invalid characters in version'
-		unless LaxVersionStr->check( $version );
+		unless LaxVersionStr->check( $version );  ## no critic (Modules::RequireExplicitInclusion)
 
 	my $doc = $self->ppi_document_for_file($file);
 
@@ -47,16 +55,16 @@ sub munge_file {
 	my $version_regex
 		= q{
                   ^
-                  (\s*)           # capture all whitespace before comment
+                  (\s*)              # capture all whitespace before comment
                   (
-                    \#\s*VERSION  # capture # VERSION
-                    \b            # and ensure it ends on a word boundary
-                    [             # conditionally
-                      [:print:]   # all printable characters after VERSION
-                      \s          # any whitespace including newlines see GH #5
-                    ]*            # as many of the above as there are
+                    \#\#?\s*VERSION  # capture # VERSION or ## VERSION
+                    \b               # and ensure it ends on a word boundary
+                    [                # conditionally
+                      [:print:]      # all printable characters after VERSION
+                      \s             # any whitespace including newlines - GH #5
+                    ]*               # as many of the above as there are
                   )
-                  $               # until the EOL}
+                  $                  # until the EOL}
 		;
 
 	my $munged_version = 0;
@@ -103,7 +111,7 @@ Dist::Zilla::Plugin::OurPkgVersion - No line insertion and does Package version
 
 =head1 VERSION
 
-version 0.08
+version 0.11
 
 =head1 SYNOPSIS
 
@@ -188,6 +196,18 @@ becomes
 	our $VERSION = '0.1.0'; # VERSION: generated by DZP::OurPkgVersion
 	...
 
+you can also use perltidy's default static side comments (##)
+
+	...
+	## VERSION
+	...
+
+becomes
+
+	...
+	our $VERSION = '0.1.0'; ## VERSION
+	...
+
 Also note, the package line is not in any way significant, it will insert the
 C<our $VERSION> line anywhere in the file before C<# VERSION> as many times as
 you've written C<# VERSION> regardless of whether or not inserting it there is
@@ -215,12 +235,20 @@ the number of files to search to only be modules and executables.
 
 tells which files to munge, see L<Dist::Zilla::Role::FileMunger>
 
+=item finder
+
+Override the default L<FileFinder|Dist::Zilla::Role::FileFinder> for
+finding files to check and update. The default value is C<:InstallModules>
+and C<:PerlExecFiles> (when available; otherwise C<:ExecFiles>)
+-- see also L<Dist::Zilla::Plugin::ExecDir>, to make sure the script
+files are properly marked as executables for the installer.
+
 =back
 
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-https://github.com/plicease/dist-zilla-plugin-ourpkgversion/issues
+L<https://github.com/plicease/dist-zilla-plugin-ourpkgversion/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -228,7 +256,7 @@ feature.
 
 =head1 CONTRIBUTORS
 
-=for stopwords Alexandr Ciornii Alexei Znamensky Christian Walde Christopher J. Madsen David Golden Graham Ollis
+=for stopwords Alexandr Ciornii Alexei Znamensky Christian Walde Christopher J. Madsen David Golden Graham Ollis Ian Sealy Stephan Loyd
 
 =over 4
 
@@ -260,6 +288,14 @@ Graham Ollis <perl@wdlabs.com>
 
 Graham Ollis <plicease@cpan.org>
 
+=item *
+
+Ian Sealy <git@iansealy.com>
+
+=item *
+
+Stephan Loyd <stephanloyd9@gmail.com>
+
 =back
 
 =head1 AUTHORS
@@ -278,7 +314,7 @@ Grahan Ollis <plicease@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Caleb Cushing.
+This software is Copyright (c) 2017 by Caleb Cushing.
 
 This is free software, licensed under:
 
